#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <QComboBox>
#include "custom_plugin.h"
#include "firefox_plugin.h"
#include "flash_plugin.h"
#include "kiosk_plugin.h"
#include "mirage_plugin.h"
#include "remote_plugin.h"
#include "vlc_plugin.h"
#include <QStyleFactory>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    QApplication::setStyle("GTK+");
    ui->setupUi(this);
    buildModuleList();
    //qDebug() << "nom du theme:" << Utils::getIconTheme();
    QIcon::setThemeName(Utils::getIconTheme());

    QFont f1( "Arial", 16, QFont::Bold);
    ui->lbl_selected->setFont(f1);
    ui->pushB_test->setIcon(QIcon::fromTheme("media-playback-start"));
    ui->pushB_validate->setIcon(QIcon::fromTheme("gtk-ok"));
    ui->lbl_selected->setStyleSheet("QLabel { background-color : white; color : noir; }");
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::buildModuleList()
{
    Plugin *none =new Plugin();
    plugins.append(none);
    Plugin *custom = new Custom_plugin();
    plugins.append(custom);
    Plugin *firefox = new Firefox_plugin();
    plugins.append(firefox);
    Plugin *kiosk = new Kiosk_plugin();
    plugins.append(kiosk);
    Plugin *mirage = new Mirage_plugin();
    plugins.append(mirage);
    Plugin *vlc = new Vlc_plugin();
    plugins.append(vlc);

#ifndef __arm__
    Plugin *flash = new Flash_plugin();
    plugins.append(flash);
    Plugin *remote = new Remote_plugin();
    plugins.append(remote);
#endif

    foreach(Plugin *plugin, plugins)
    {
        ui->comboB_select->addItem(plugin->getIcon(),plugin->getGenericName());
    }

    QString selected = Utils::ReadEntry(CONFFILE,"selected","default");
    for(int i=0;i<plugins.size();i++)
    {
        if(plugins[i]->getName() == selected)
        {
            ui->comboB_select->setCurrentIndex(i);
        }
    }
    if(Utils::ReadEntry(CONFFILE,"noscreensaver","default") == "true")
        ui->checkB_saver->setChecked(true);
    if(Utils::ReadEntry(CONFFILE,"hidecursor","default") == "true")
        ui->checkB_cursor->setChecked(true);

    ui->timeEdit_startup->setValue(Utils::ReadEntry(CONFFILE, "delay", "default").toInt());
}

void MainWindow::on_comboB_select_currentIndexChanged(int index)
{
    ui->lbl_selected->setText(plugins[index]->getGenericName());
    ui->lbl_iconSelected->setPixmap(plugins[index]->getIcon().pixmap(32,32));
    clearLayout(ui->infoLayout);
    plugins[index]->getPluginConfig(ui->infoLayout);
    plugins[index]->readConfig();
    resize(0,0);
}

void MainWindow::clearLayout(QLayout* layout, bool deleteWidgets)
{
    while (QLayoutItem* item = layout->takeAt(0))
    {
        if (deleteWidgets)
        {
            if (QWidget* widget = item->widget())
                delete widget;
        }
        if (QLayout* childLayout = item->layout())
            clearLayout(childLayout, deleteWidgets);
        delete item;
    }
}

void MainWindow::on_pushB_validate_clicked()
{
    writeConfig();
    close();
}

void MainWindow::writeConfig()
{
    Plugin *selected = plugins[ui->comboB_select->currentIndex()]->writeConfig();
    QString newFile;
    newFile = "[default]\n"
            "selected=" + selected->getName() + "\n"
            "command=" + selected->getCommand() + "\n";

    if(ui->checkB_saver->isChecked())
        newFile += "noscreensaver=true\n";
    else
        newFile += "noscreensaver=false\n";

    if(ui->checkB_cursor->isChecked())
        newFile += "hidecursor=true\n";
    else
        newFile += "hidecursor=false\n";

    int delay = ui->timeEdit_startup->value() ;
    newFile += "delay=" + QString::number(delay) + "\n\n";

    QFile file(CONFFILE);
    if(file.open(QFile::ReadWrite |
                 QFile::Text))
    {
        bool keep = true;
        QTextStream in(&file);
        while (!in.atEnd())
        {
            QString line = in.readLine();
            if(line == "[default]")
                keep = false;
            if(keep)
                newFile += line + "\n";
            if(line == "")
                keep = true;

        }
        file.close();
        if(file.open(QFile::WriteOnly | QIODevice::Truncate |
                     QFile::Text))
        {
            QTextStream out(&file);
            out << newFile;
            file.flush();
            file.close();
        }
    }
}

void MainWindow::on_pushB_test_clicked()
{
    writeConfig();
    QProcess::startDetached("asrun");
}
